--[[
Copyright (c) 2009, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

if( not CalendarBroker ) then
    return;
end--if

local L = LibStub( "AceLocale-3.0" ):GetLocale( "Calendar_Broker" );

local GEMCalendarHandler = {};
local CALENDAR_NAME = L["GEM3"];

function GEMCalendarHandler:CanEnableCalendar()
    return GEM3_RegisterCallback and GEM3_Events;
end--GEMCalendarHandler:CanEnableCalendar()

function GEMCalendarHandler:SetupCalendarSupport( calendarMain )
    if( GEM3_RegisterCallback ) then
        local function GEM3Callback()
            calendarMain:CalendarUpdate( CALENDAR_NAME );
        end--GEM3Callback()

        GEM3_RegisterCallback( "OnSubscribed", GEM3Callback );
        GEM3_RegisterCallback( "OnUnSubscribed", GEM3Callback );
        GEM3_RegisterCallback( "OnSubscriptionChanged", GEM3Callback );
        GEM3_RegisterCallback( "OnKickedFromEvent", GEM3Callback );
        GEM3_RegisterCallback( "OnUpdateEvent", GEM3Callback );
    end--if
end--GEMCalendarHandler:SetupCalendarSupport( calendarMain )

function CalendarBroker:GetCalendar( calendarMain )
    -- if GEM is loaded, then add the events that I am subscribed to
    if( GEM3_Events and GEM3_Events[GEM3_Realm] and GEM3_Events[GEM3_Realm].subscribed ) then
        for i, event in ipairs( GEM3_Events[GEM3_Realm].subscribed ) do
            local myevent = event[UnitName( "player" )];
            
            if( myevent ) then
                local EVloc = myevent.ev_place;
                -- GEM3 uses UTC for all times
                local EVsec = myevent.ev_date;
                local EVtype = myevent.ev_type;
                local type = "OTHER";
    
                -- TODO: Set type based on channel...
                if( EVtype == GEM3_EVT_TYPE_NONE ) then
                    type = "OTHER";
                elseif( EVtype == GEM3_EVT_TYPE_TEST ) then
                    type = "OTHER";
                elseif( EVtype == GEM3_EVT_TYPE_RESET ) then
                    type = "RAID";
                elseif( EVtype == GEM3_EVT_TYPE_LFG ) then
                    type = "PLAYER";
                elseif( EVtype == GEM3_EVT_TYPE_POLL ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_PLAYER_AVALABILITY ) then
                    type = "PLAYER";
                elseif( EVtype == GEM3_EVT_TYPE_RAID_AVAILABILITY ) then
                    type = "RAID";
                elseif( EVtype == GEM3_EVT_TYPE_INSTANCE5 ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_INSTANCE5_BC ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_INSTANCE5_WOTLK ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_INSTANCE5_BCH ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_INSTANCE5_WOTLKH ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_RAID ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_RAID_BC ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_RAID_WOTLK ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_PVP ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_GUILD_EVENT ) then
                    type = "GUILD";
                elseif( EVtype == GEM3_EVT_TYPE_GUILD_OFFICERMEETING ) then
                    type = "GUILD";
                end--if
                calendarMain:AddEvent( EVsec, event.ev_duration or ( 1 * CALENDARBROKER_SECPERHOUR ), EVloc, type, CALENDAR_NAME, i );
            end--if
        end--for
    end--if
end--GEMCalendarHandler:GetCalendar( calendarMain )

function GEMCalendarHandler:GetEventInfo( calendarMain, id )
    local returnVal = TR:GetTable();
    
    return returnVal;
end--GEMCalendarHandler:GetEventInfo( calendarMain, id )

CalendarBroker.Calendars[CALENDAR_NAME] = GEMCalendarHandler;
